<?php
/**
 * Themaga template functions.
 *
 * @author  ThemeCountry
 * @since 	1.0.0
 * @package themaga
 */

if ( ! function_exists( 'themaga_skip_links' ) ) {
	/**
	 * Skip links
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function themaga_skip_links() {
		?>

			<a class="skip-link screen-reader-text" href="#site-navigation"><?php esc_attr_e( 'Skip to navigation', 'themaga' ); ?></a>
			<a class="skip-link screen-reader-text" href="#content"><?php esc_attr_e( 'Skip to content', 'themaga' ); ?></a>

		<?php
	}
}


if ( ! function_exists( 'themaga_site_branding' ) ) {
	/**
	 * Site branding wrapper and display
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function themaga_site_branding() {
		?>

			<div id="logo" class="site-branding">
				<?php themaga_site_title_or_logo(); ?>
			</div>

		<?php
	}
}


if ( ! function_exists( 'themaga_site_title_or_logo' ) ) {
	/**
	 * Display the site title or logo
	 *
	 * @since 1.0.0
	 * @param bool $echo Echo the string or return it.
	 * @return string
	 */
	function themaga_site_title_or_logo( $echo = true ) {

		if ( function_exists( 'the_custom_logo' ) && has_custom_logo() ) {

			$logo = get_custom_logo();
			$html = is_home() ? '<h1 class="logo">' . $logo . '</h1>' : $logo;

		} elseif ( function_exists( 'jetpack_has_site_logo' ) && jetpack_has_site_logo() ) {

			// Copied from jetpack_the_site_logo() function.
			$logo    = site_logo()->logo;
			$logo_id = get_theme_mod( 'custom_logo' ); // Check for WP 4.5 Site Logo
			$logo_id = $logo_id ? $logo_id : $logo['id']; // Use WP Core logo if present, otherwise use Jetpack's.
			$size    = site_logo()->theme_size();
			$html    = sprintf( '<a href="%1$s" class="site-logo-link" rel="home" itemprop="url">%2$s</a>',
				esc_url( home_url( '/' ) ),
				wp_get_attachment_image(
					$logo_id,
					$size,
					false,
					array(
						'class'     => 'site-logo attachment-' . $size,
						'data-size' => $size,
						'itemprop'  => 'logo'
					)
				)
			);

			$html = apply_filters( 'jetpack_the_site_logo', $html, $logo, $size );

		} else {

			$tag = is_home() ? 'h1' : 'h2';

			$html = '<' . esc_attr( $tag ) . ' class="site-title"><a href="' . esc_url( home_url( '/' ) ) . '" rel="home">' . esc_html( get_bloginfo( 'name' ) ) . '</a></' . esc_attr( $tag ) .'>';

		}

		if ( ! $echo ) {
			return $html;
		}

		echo $html;
	}


}

if ( ! function_exists( 'themaga_header_right_wrapper_open' ) ) {

	function themaga_header_right_wrapper_open() {

		echo '<div class="header-wrap-right">';
	}

}

if ( ! function_exists( 'themaga_header_right_wrapper_close' ) ) {

	function themaga_header_right_wrapper_close() {

		echo '</div><!-- .header-wrap-right -->';
	}

}

if ( ! function_exists( 'themaga_primary_navigation' ) ) {

	function themaga_primary_navigation() {

		if ( has_nav_menu( 'primary' ) ) :
		?>
			<nav id="site-navigation" class="main-navigation default-menustyle" role="navigation">
				<a class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php esc_html_e( 'Menu', 'themaga' ); ?></a>
				<?php
					// Display Primary Navigation.
					wp_nav_menu( array(
						'theme_location' => 'primary',
						'menu_id' 		 => 'primary-navigation',
						'container' 	 => '',
						'menu_class' 	 => 'main-navigation-menu',
						)
					);

				?>

			</nav><!-- #site-navigation -->

		<?php
		endif;
	}
}

if ( ! function_exists( 'themaga_topbar_search' ) ) {

	function themaga_topbar_search() {

		?>

		<div class="topbar-search">
		 	<a id="trigger-overlay">
		 		<i class="fa fa-search"></i>
		 	</a>
		</div><!-- .top-search -->

	<?php


	}
}



if ( ! function_exists( 'themaga_back_to_top' ) ) {


	/**
	 * Button back to top.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	function themaga_back_to_top() {

		$back_to_top = themaga_get_theme_option( 'themaga_back_to_top' , '1' );

		if ( $back_to_top == 1) { echo '<span class="back-to-top"><i class="fa fa-chevron-up"></i></span>'; }
	}

}

if ( ! function_exists( 'themaga_paging_nav' ) ) :
/**
 * Display navigation to next/previous set of posts when applicable.
 */
function themaga_paging_nav() {

	the_posts_pagination( array(
		'prev_text'      	=> __( '<i class="fa fa-angle-left"></i>', 'themaga' ),
		'next_text'		  => __( '<i class="fa fa-angle-right"></i>', 'themaga' ),
		'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'themaga' ) . ' </span>',
	) );

}
endif;

if ( ! function_exists( 'themaga_post_thumbnail' ) ) :
	/**
	 * Display Post Thumbnail
	 */
	function themaga_post_thumbnail() {

		$size = apply_filters( 'themaga_post_thumbnail_size', 'themaga-small-thumbnail' );
		$show = apply_filters( 'themaga_post_thumbnail_show', true );

		if ( $show ) {
			?>
				<div class="post-thumbnai">
					<a href="<?php the_permalink() ?>" rel="bookmark">

						<?php if ( has_post_thumbnail() ) : ?>

							<?php themaga_the_post_thumbnail( $size, '', true ) ?>

						<?php else : ?>

							<img class="wp-post-image" src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/themaga-feature-small-thumbnail.jpg" />

						<?php endif; ?>

					 </a>
				</div>
			<?php
		}

	}

endif;

function themaga_title() {
	?>

		<div class="wraper-header-single">
			<div class="container">
				<header class="entry-header">

					<?php do_action('themaga_before_single_title'); ?>

					<?php the_title( '<h1 class="entry-title single-title">', '</h1>' ); ?>

					<?php do_action('themaga_after_single_title'); ?>

				</header>
			</div>
		</div>


	<?php
}

if ( ! function_exists( 'themaga_post_header' ) ) :

			/**
	 * Display post single header
	 */

	function themaga_post_header() {

		?>

		<header class="entry-header">

			<?php

			do_action( 'themaga_before_post_title');

			if ( is_single() ) {

				the_title( '<h1 class="entry-title single-title">', '</h1>' );
			} else {

				the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' );
			}

			do_action( 'themaga_after_post_title');

			?>

		</header><!-- .entry-header -->

		<?php

	}

endif;


if ( ! function_exists( 'themaga_single_post_thumbnail' ) ) :
	/**
	 * Display Post Thumbnail
	 */
	function themaga_single_post_thumbnail() {

		$enable_thumbnail = themaga_get_theme_option( 'single_post_show_thumbnail', true );

		if ( $enable_thumbnail ) :

			?>
				<p>
					<?php the_post_thumbnail( 'themaga-feature-thumbnail') ?>
				</p>
			<?php

		endif;

	}

endif;

if ( ! function_exists( 'themaga_paging_nav' ) ) :
	/**
	 * Display navigation to next/previous set of posts when applicable.
	 */
	function themaga_paging_nav() {

		the_posts_pagination( array(
			'prev_text'				=> __( '<i class="fa fa-angle-left"></i>', 'themaga' ),
			'next_text'				=> __( '<i class="fa fa-angle-right"></i>', 'themaga' ),
			'before_page_number'	=> '<span class="meta-nav screen-reader-text">' . __( 'Page', 'themaga' ) . ' </span>',
		) );

	}
endif;


if ( ! function_exists( 'themaga_post_nav' ) ) {

	/**
	 * Display navigation to next/previous post when applicable.
	 */
	function themaga_post_nav() {

		$args = array(
			'next_text' => '%title',
			'prev_text' => '%title',
		);

		$enable_postnav = themaga_get_theme_option('single_post_show_nav', true);

		if ( $enable_postnav ) {

			the_post_navigation( $args );

		}
	}

}


if ( ! function_exists( 'themaga_display_comments' ) ) {
	/**
	 * Themaga display comments
	 *
	 * @since  1.0.0
	 */
	function themaga_display_comments() {
		// If comments are open or we have at least one comment, load up the comment template.
		if ( comments_open() || '0' != get_comments_number() ) :
			comments_template();
		endif;
	}
}



if ( ! function_exists( 'themaga_post_on' ) ) :

	/**
	 * Display post on
	 */

	function themaga_post_on() {


		$posted_on = apply_filters( 'themaga_posted_on_show', true );

		?>
			<?php if ( 'post' === get_post_type() && $posted_on ) : ?>
				<?php themaga_posted_on(); ?>
			<?php endif; ?>

		<?php
	}

endif;

if ( ! function_exists( 'themaga_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function themaga_posted_on() {
	global $post;
	$author_id=$post->post_author;


	$meta_options = themaga_get_theme_option( 'general_posts_metadata', array('date', 'category', 'tag', 'author') );

	if(empty($meta_options))
		return;

	if(is_array($meta_options))
		$meta_options = array_flip($meta_options);

	echo '<div class="entry-meta">';

	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%3$s">%4$s</time>';
	}

	$categories_list = get_the_category_list( esc_html__( ', ', 'themaga' ) );

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

	$byline = '<a class="url fn n" href="' . esc_url( get_author_posts_url( $author_id ) ) . '">' . esc_html( get_the_author_meta( 'display_name', $author_id ) ) . '</a>';

	if ( isset ( $meta_options['date'] ) ) {

		printf( '<span class="posted-on"> ' . esc_html__( ' %1$s ', 'themaga' ) . ' </span>', $posted_on );
	}

	if ( isset ( $meta_options['author'] ) ) {

		printf( '<span class="author">' . esc_html__( 'By %1$s ', 'themaga' ) . ' </span>', $byline );
	}

	if ( isset ( $meta_options['category'] ) && $categories_list ) {

		printf( '<span class="cat-links"> ' . esc_html__( ' %1$s ', 'themaga' ) . ' </span>', $categories_list ); // WPCS: XSS OK.
	}

	if ( isset( $meta_options['comment'] ) ) :

		if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link">';
			/* translators: %s: post title */
			comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'themaga' ), array( 'span' => array( 'class' => array() ) ) ), get_the_title() ) );
			echo '</span>';
		}

	endif;

	echo '</div><!-- .entry-meta -->';

}
endif;

if ( ! function_exists( 'themaga_single_post_title' ) ) {
	/**
	 * Display the Single Post Title
	 *
	 * @since 1.0.0
	 */
	function themaga_single_post_title() {

		//add_action('themaga_content_top', 'themaga_title');

		if ( is_single() ) {

		?>
			<div class="wraper-header-single">
				<div class="container">
					<header class="entry-header">

						<?php do_action('themaga_before_single_title'); ?>

						<?php the_title( '<h1 class="entry-title single-title">', '</h1>' ); ?>

						<?php do_action('themaga_after_single_title'); ?>
					</header>
				</div>
			</div>
			<?php

		}

	}

}

if ( ! function_exists( 'themaga_tags_list' ) ) {
	/**
	 * Display the Tag list
	 *
	 * @since 1.0.0
	 */
	function themaga_tags_list() {

		$tags_list = get_the_tag_list( '', esc_html__( ' ', 'themaga' ) );

		$enable_tags = themaga_get_theme_option( 'single_post_show_related_topic', '1' );

		if ( $enable_tags && $tags_list  ) {

		printf( '<footer class="entry-footer"><span class="tags-links">' . '<h4>' . esc_html__( 'Related Topic:', 'themaga' ) . '</h4>'  .  esc_html__( ' %1$s ', 'themaga' ) . ' </span></footer>', $tags_list ); // WPCS: XSS OK.
		}

	}

}





if ( ! function_exists( 'themaga_post_content' ) ) {
	/**
	 * Display the post content with a link to the single post
	 *
	 * @since 1.0.0
	 */
	function themaga_post_content() {

		$excerpt = apply_filters( 'general_post_show_excerpt', true );

		?>
		<div class="entry-content">
		<?php

		/**
		 * Functions hooked in to themaga_post_content_before action.
		 *
		 * @hooked themaga_post_thumbnail - 10
		 */
		do_action( 'themaga_post_content_before' );

		if ( $excerpt ) {

			the_excerpt();

		} else {

			the_content(
				sprintf(
					__( 'Continue reading %s', 'themaga' ),
					'<span class="screen-reader-text">' . get_the_title() . '</span>'
				)
			);
		}

		do_action( 'themaga_post_content_after' );

		wp_link_pages( array(
			'before' => '<div class="page-links">' . __( 'Pages:', 'themaga' ),
			'after'  => '</div>',
		) );
		?>
		</div><!-- .entry-content -->

		<?php
	}
}

if ( ! function_exists( 'themaga_entry_footer' ) ) {
	/**
	 * Display the post content with a link to the single post
	 *
	 * @since 1.0.0
	 */
	function themaga_entry_footer() {

		?>
		<div class="entry-footer">
		<?php

		/**
		 * Functions hooked in to themaga_post_content_before action.
		 *
		 * @hooked themaga_entry_footer - 10
		 */
		do_action( 'themaga_entry_footer_before' );

		do_action( 'themaga_entry_footer' );

		do_action( 'themaga_entry_footer_after' );

		?>

		</div><!-- .entry-footer -->

		<?php
	}
}


if ( ! function_exists( 'themaga_footer_widgets' ) ) {
	/**
	 * Display the footer widget regions.
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function themaga_footer_widgets() {
		$rows    = intval( apply_filters( 'themaga_footer_widget_rows', 1 ) );
		$regions = intval( apply_filters( 'themaga_footer_widget_columns', 4 ) );

		for ( $row = 1; $row <= $rows; $row++ ) :

			// Defines the number of active columns in this footer row.
			for ( $region = $regions; 0 < $region; $region-- ) {
				if ( is_active_sidebar( 'footer-' . strval( $region + $regions * ( $row - 1 ) ) ) ) {
					$columns = $region;
					break;
				}
			}

			if ( isset( $columns ) ) : ?>
				<div class=<?php echo '"footer-widgets row-' . strval( $row ) . ' col-' . strval( $columns ) . ' fix"'; ?>><?php

					for ( $column = 1; $column <= $columns; $column++ ) :
						$footer_n = $column + $regions * ( $row - 1 );

						if ( is_active_sidebar( 'footer-' . strval( $footer_n ) ) ) : ?>

							<div class="block footer-widget-<?php echo strval( $column ); ?>">
								<?php dynamic_sidebar( 'footer-' . strval( $footer_n ) ); ?>
							</div><?php

						endif;
					endfor; ?>

				</div><!-- .footer-widgets.row-<?php echo strval( $row ); ?> --><?php

				unset( $columns );

			endif;
		endfor;
	}
}


if ( ! function_exists( 'themaga_single_post_header' ) ) {
	/**
	 * Display single post header
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function themaga_single_post_header() {
		?>
		<?php
	}
}

if ( ! function_exists( 'themaga_inner_wrapper' ) ) {
	/**
	 * Display inner wrapper
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function themaga_inner_wrapper() {
		?>
		<div class="site-info clearfix">

			<?php echo "themaga_inner_wrapper"; ?>

		</div><!-- .site-info -->
		<?php
	}
}

if ( ! function_exists( 'themaga_post_single_content' ) ) {
	/**
	 * Display post content single
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function themaga_post_single_content() {
		?>

		<div class="entry-content">
		<?php

			/**
			 * Functions hooked in to themaga_post_content_before action.
			 *
			 * @hooked themaga_post_thumbnail - 10
			 */
			do_action( 'themaga_post_single_content_before' );

			the_content(
				sprintf(
					__( 'Continue reading %s', 'themaga' ),
					'<span class="screen-reader-text">' . get_the_title() . '</span>'
				)
			);

			do_action( 'themaga_post_single_content_after' );

			wp_link_pages( array(
				'before' => '<div class="page-links">' . __( 'Pages:', 'themaga' ),
				'after'  => '</div>',
			) );
		?>
		</div><!-- .entry-content -->

		<?php
	}
}

if ( ! function_exists( 'themaga_get_sidebar' ) ) {
	/**
	 * Display themag sidebar
	 *
	 * @uses get_sidebar()
	 * @since 1.0.0
	 */
	function themaga_get_sidebar() {

		get_sidebar();

	}

}

if ( ! function_exists( 'themaga_credit' ) ) {
	/**
	 * Display the theme credit
	 *
	 * @since  1.0.0
	 * @return void
	 */
	function themaga_credit() {
		?>
		<div class="copyright">

				<?php echo esc_html( apply_filters( 'themaga_copyright_text', $content = '&copy; ' . get_bloginfo( 'name' ) . ' ' . date( 'Y' ) ) ); ?>

				<?php if ( apply_filters( 'themaga_credit_link', true ) ) { ?>

					<?php echo ( sprintf(__( '&bull; <a href="%s" rel="author" title="Themaga - The best free WordPress blog theme for WordPress"> Themaga</a> powered by <a href="http://wordpress.org/">WordPress</a>', 'themaga' ), 'https://themecountry.com/themes/themaga/' )); ?>


				<?php } ?>

		</div><!-- .copyright -->
		<?php
	}
}

if ( ! function_exists( 'themaga_page_header' ) ) {
	/**
	 * Display the post header with a link to the single post
	 *
	 * @since 1.0.0
	 */
	function themaga_page_header() {
		?>
		<header class="entry-header">
			<?php
				the_title( '<h1 class="entry-title">', '</h1>' );
			?>
		</header><!-- .entry-header -->
		<?php
	}
}

if ( ! function_exists( 'themaga_page_content' ) ) {
	/**
	 * Display the post content with a link to the single post
	 *
	 * @since 1.0.0
	 */
	function themaga_page_content() {
		?>
		<div class="entry-content">
			<?php the_content(); ?>
			<?php
				wp_link_pages( array(
					'before' => '<div class="page-links">' . __( 'Pages:', 'themaga' ),
					'after'  => '</div>',
				) );
			?>
		</div><!-- .entry-content -->
		<?php
	}
}

if ( ! function_exists( 'themaga_feature_homepage' ) ) :

	/**
	 * Display Feature Homepage.
	 *
	 * @since 1.0.1
	 */

	function themaga_feature_homepage() {

		if ( is_page_template('template-homepage.php') ) {

			$enable_featured = themaga_get_theme_option( 'enable_featured', true);

			// Back when disable
			if($enable_featured!=true)
			return;

			$featured_cat = themaga_get_theme_option( 'themaga_select_list', 0 );

			// Get latest posts from database
			$args = array(
				'posts_per_page' => 4,
				'ignore_sticky_posts' => true
			);

			if ( $featured_cat > 0 ) {
				$args['cat'] = $featured_cat;
			}

			$i = 0;

			$posts_query = new WP_Query( $args );

			// Check if there are posts
			if( $posts_query->have_posts() ) :

				?>

				<div class="FeatureBox featureWrap">

						<?php

						// Display Posts
						while( $posts_query->have_posts() ) :

							$posts_query->the_post();

							if( isset($i) and $i <= 3 ) :

							if ( $i == 0 ) {

								$featured_image = get_the_post_thumbnail_url( get_the_ID(), 'themaga-feature-thumbnail' );


							} elseif ($i == 1) {

								$featured_image = get_the_post_thumbnail_url( get_the_ID(), 'themaga-feature-thumbnail' );

							} else {

								$featured_image = get_the_post_thumbnail_url( get_the_ID(), 'themaga-small-feature-thumbnail' );

							}

							$background_image = 'url(' . esc_url( $featured_image ) . ')';

								?>

								<div class="featurePost" style="background-image: <?php echo $background_image; ?>"; >

									<div class="content-wrapper">
										<header class="entry-header">
											<?php themaga_meta_category() ?>
											<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
											<?php if ( $i == 0 ) { themaga_feature_post_meta(); } ?>

											</header>

									</div> <!-- .content-wrapper -->

								</div>

							<?php

							endif; $i++;

						endwhile;

						wp_reset_query();

						?>


				</div>

				<?php

			endif;

		}


	}

endif;

if ( ! function_exists( 'themaga_homepage_section_title' ) ) :

	function themaga_homepage_section_title( $title_section, $cat_id ) {

		if( $title_section ) :

			$category_link = get_category_link( $cat_id );

			?>

			<div class="section-title-wrapper">
				<h3 class="section-title">
					<?php if ( $category_link ) : ?>
						<a href="<?php echo esc_url( $category_link ); ?>"><?php echo esc_html( $title_section ); ?></a>
					<?php else : ?>
							<?php echo esc_html( $title_section ); ?>
					<?php endif; ?>
				</h3>
			</div>

			<?php

		endif;

	}

endif;

if ( ! function_exists( 'themaga_meta_category' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function themaga_meta_category() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( ', ' );
		if ( $categories_list ) {
			printf( '<div class="cat-links 777">' . esc_html( '%1$s', 'themaga' ) . '</div>', $categories_list ); // WPCS: XSS OK.
		}
	}
}
endif;

if ( ! function_exists( 'themaga_more_link' ) ) :
	/**
	 * Displays the more link on posts
	 */
	function themaga_more_link() {
		?>

		<a href="<?php echo esc_url( get_permalink() ) ?>"  title="<?php the_title() ?>" class="more-link"><span><?php esc_html_e( 'Learn More', 'themaga' ); ?></span></a>

		<?php
	}
endif;

if ( ! function_exists( 'themaga_feature_post_meta' ) ) :
	/**
	 * Displays the feature Post meta
	 */
	function themaga_feature_post_meta() {

		do_action( 'themaga_feature_post_meta');
	}

endif;

if ( ! function_exists( 'themaga_feature_author' ) ) :
	/**
	 * Displays the feature Post meta
	 */
	function themaga_feature_author() {

		$byline = '<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . get_the_author() . '</a>';

			printf( '<span class="author">' . esc_html__( 'By %1$s ', 'themaga' ) . ' </span>', $byline );

	}

endif;

if ( ! function_exists( 'themaga_date_posted_on' ) ) {

	function themaga_date_posted_on() {

		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

		/* translators: %1$s: Date link*/

		printf( '<span class="post-date">' . esc_html__( ' %1$s ', 'themaga' ) . ' </span>', $time_string ); // WPCS: XSS OK.

	}

}

if ( ! function_exists( 'themaga_post_meta_wrapper_open' ) ) :
	/**
	 * Displays the feature Post meta open
	 */
	function themaga_post_meta_wrapper_open() {

		echo '<div class="post-meta">';

	}

endif;

if ( ! function_exists( 'themaga_post_meta_wrapper_close' ) ) :
	/**
	 * Displays the feature Post meta open
	 */
	function themaga_post_meta_wrapper_close() {

		echo '</div>';

	}

endif;

/*
|------------------------------------------------------------------------------
| Customize Tag
|------------------------------------------------------------------------------
*/
add_filter('widget_tag_cloud_args','set_tag_cloud_sizes');
function set_tag_cloud_sizes($args) {
	$args['largest'] = 16;
	$args['smallest'] = 16;
	$args['unit'] = 'px';
	return $args;
}


/**
|------------------------------------------------------------------------------
| Excerpt
|------------------------------------------------------------------------------
|
*/

function themaga_excerpt_length( $length ) {

	//$theme_options = hongblog_theme_options();
	$excerpt_length = themaga_get_theme_option('general_post_excerpt_length' , 20);

	$number = intval ($excerpt_length) > 0 ?  intval ($excerpt_length) : $length;
	return $number;
}
add_filter( 'excerpt_length', 'themaga_excerpt_length', 999 );

function themaga_excerpt_more( $more ) {

	return themaga_get_theme_option( 'general_post_show_excerpt_more' , ' ...' );

}
add_filter('excerpt_more', 'themaga_excerpt_more');


/**
|------------------------------------------------------------------------------
| Search Header
|------------------------------------------------------------------------------
|
*/

if ( ! function_exists( 'themaga_search_overlay' ) ) {

	function themaga_search_overlay() { ?>

		<div id="search-overlay">
			<div class="search-overlay-inner">
				<i class="fas fa-times search-close"></i>
				<?php
					/**
					 * Search Form
					 *
					 * @search from wordpress
					 */
					echo get_search_form();
				?>
				<p class="search-label"><?php _e( 'Type keyword to search','themaga' ) ?></p>
			</div>
		</div>

	<?php
	}
}

/**
|------------------------------------------------------------------------------
| Ads Below Featured
|------------------------------------------------------------------------------
|
*/

if ( ! function_exists( 'themaga_ads_under_featured' ) ) {

	function themaga_ads_under_featured() {
		if ( is_active_sidebar( 'adsfeatured-1' ) && (is_home() || is_front_page()) ) :

			?>

			<div class="adsFeatured ads">

				<div class="container">
					<?php dynamic_sidebar( 'adsfeatured-1' ); ?>
				</div>

			</div>

			<?php

		endif;

	}
}

/**
|------------------------------------------------------------------------------
| Ads Footer
|------------------------------------------------------------------------------
|
*/

if ( ! function_exists( 'themaga_ads_footer' ) ) {

	function themaga_ads_footer() {
		if ( is_active_sidebar( 'adsfooter-1' ) && (is_home() || is_front_page()) ) :

			?>

			<div class="adsfooter ads">

				<div class="container">
					<?php dynamic_sidebar( 'adsfooter-1' ); ?>
				</div>

			</div>

			<?php

		endif;

	}
}

/**
|------------------------------------------------------------------------------
| Function Homepage Lastest Post Style
|------------------------------------------------------------------------------
*/

if ( ! function_exists( 'themaga_homepage_latest_post_style' ) ) {

	function themaga_homepage_latest_post_style() {

		echo '<div class="container">';

		do_action('themaga_homepage_latest_post_style');

		echo "</div>";

	}
}

/**
|------------------------------------------------------------------------------
| Menu Overlay
|------------------------------------------------------------------------------
*/

if ( ! function_exists( 'themaga_menu_overlay' ) ) {

	function themaga_menu_overlay() {

		if ( has_nav_menu( 'primary' ) ) : ?>

			<div class="menu-overlay"></div>

		<?php


		endif;

	}
}

if ( ! function_exists( 'themaga_render_post_homepage' ) ) {

	function themaga_render_post_homepage($row, $number_post, $layout_box) {

		$query_arguments = array(
					'posts_per_page' => $number_post,
					'ignore_sticky_posts' => true,
				);

		$posts_query = new WP_Query( $query_arguments );

		if( $posts_query->have_posts() ) :

			// Display Posts
			while( $posts_query->have_posts() ) :

				$posts_query->the_post();

				?>

				<article id="post-<?php the_ID(); ?>" <?php post_class( 'large-post ' . $layout_box ); ?>>

					<div class="content-wrapper">

						<div class="featured-thumbnail">
							<a href="<?php the_permalink() ?>" rel="bookmark">

								<?php if ( has_post_thumbnail() ) : ?>

									<?php the_post_thumbnail( 'themaga-feature-thumbnail' ); ?>

								<?php else : ?>

						 			<img class="wp-post-image" src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/themaga-feature-thumbnail.jpg" />

						 		<?php endif; ?>

							</a>
						</div>

						<header class="entry-header">
							<?php themaga_meta_category() ?>
							<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
						</header>

					</div>

				</article>

				<?php

			endwhile;

		endif;

	}
}

/**
* New Render Posts for Homepage
*/
if ( ! function_exists( 'themaga_homepage_render' ) ) {

	/**
	* Renders style on homepage
	* @since 1.0.0
	* @return void
	*/
	function themaga_homepage_render() {

		$enable_homepage = themaga_get_theme_option( 'enable_post_sections', true);

		if ( $enable_homepage != true ) return;

		$homepage_sections = themaga_get_theme_option( 'custom_homepage_control', array() );

		if ( ! empty( $homepage_sections ) ) {

			foreach ( $homepage_sections as $hps ) {


				$cat = isset( $hps['category_post'] ) ? intval( $hps['category_post'] ) : '';
				$style = isset( $hps['box_post'] ) && ! empty( $hps['box_post'] ) ? $hps['box_post'] : 'two_box';
				$num_posts = isset( $hps['number_post'] ) ? intval( $hps['number_post'] ) : 6;
				$title_sec = isset( $hps['link_text'] ) ? $hps['link_text'] : 'Title Section';

				$args = array (
					'posts_per_page' => $num_posts == 0 ? 6 : $num_posts,
					'ignore_sticky_posts' => true
				);

				if ( $cat != '' ) {
					$args['cat'] = $cat;
				}

				$posts = get_posts( $args );

				echo '<div class="row-box">';

				if( $posts ) {
					if ( $style == 'two_box' || $style == 'three_box' ) {

						themaga_homepage_box( $posts, $style, $title_sec, $cat );

					} else {

						themaga_homepage_list( $posts, $style, $title_sec, $cat );

					}
				}

				echo '</div>';


			}
		}
	}
}

/**
* Renders style box
*
* @since 1.0.0
* @return void
*/

function themaga_homepage_box( $posts, $style, $title_sec, $cat ) {

	global $post;
	switch ( $style ) {
		case 'three_box':
			$num_posts = 3;
			$classs = 'smallPost-inner';
			$class_post = 'small-post';
			break;

		default:
			$num_posts = 2;
			$classs = 'largePost-inner';
			$class_post = 'large-post';
			break;
	}

	$split_posts = array_chunk( $posts, $num_posts );

	themaga_homepage_section_title( $title_sec, $cat );

	?>
	<div class="homepage-box <?php echo esc_attr( $style ) ?>">

		<?php
			$i = 1;
			foreach ( $split_posts as $posts ) :

				?>
				<div class="homepage-row <?php echo esc_attr( $classs ) ?> <?php echo esc_attr( 'row-' . $i ) ?>">

				<?php
				$n = 1;
				foreach ($posts as $post) :

					setup_postdata( $post );
					?>
					<!-- <div class="hbox <?php //echo esc_attr( 'hbox-'. $n ) ?>"> -->

						<article id="post-<?php the_ID(); ?>" <?php post_class( $class_post ); ?>>

											<div class="content-wrapper">

												<div class="featured-thumbnail">
													<a href="<?php the_permalink() ?>" rel="bookmark">

														<?php if ( has_post_thumbnail() ) : ?>

															<?php the_post_thumbnail( 'themaga-feature-thumbnail' ); ?>

														<?php else : ?>



															<img class="wp-post-image" src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/themaga-feature-thumbnail.jpg" />

														<?php endif; ?>

													</a>
												</div>

												<header class="entry-header">
													<?php themaga_meta_category() ?>
													<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
												</header>

												<?php if ( 'three_box' === $style ) : ?>

													<div class="post-excerpt">
														<?php themaga_post_content() ?>
													</div>

													<?php themaga_more_link() ?>

												<?php endif; ?>

											</div><!-- content-wrapper -->

						</article>

					<!-- </div> -->

					<?php

					$n++;

				endforeach;
				?>

			</div>

				<?php
				$i++;

			endforeach;
		?>
	</div>
	<?php

	wp_reset_postdata();
}

/**
* Renders list posts
* @since 1.0.0
* @return void
*/

function themaga_homepage_list( $posts, $style, $title_sec, $cat ) {

	global $post;

	themaga_homepage_section_title( $title_sec, $cat );

	echo '<div class="post-wrapper">';

	if ( 'list_box_sidebar' === $style ) :

		echo '<div class="list-post-sidebar">';

	else :

		echo '<div class="list-post-sidebar no-sidebar">';

	endif;

	foreach( $posts as $post ) :
		setup_postdata( $post );
		?>
		<article id="post-<?php the_ID(); ?>" <?php post_class( 'post-item clearfix' ); ?>>

			<div class="post-thumbnai">
				<a href="<?php the_permalink() ?>" rel="bookmark">

					<?php if ( has_post_thumbnail() ) : ?>

						<?php the_post_thumbnail( 'themaga-small-thumbnail' ); ?>

					<?php else : ?>

			 			<img class="wp-post-image" src="<?php echo esc_url( get_template_directory_uri() ); ?>/assets/images/themaga-feature-small-thumbnail.jpg" />

			 		<?php endif; ?>

				</a>
			</div>

			<header class="entry-header">
				<?php the_title( sprintf( '<h2 class="entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h2>' ); ?>
			</header>

			<div class="post-excerpt">
				<?php themaga_post_content() ?>
			</div>

			<?php themaga_entry_footer() ?>

		</article>

		<?php
	endforeach;
	echo '</div>';
	if ( 'list_box_sidebar' === $style ) { do_action( 'themaga_sidebar'  ); }

	wp_reset_postdata();
}
